| set_space | R Documentation |
change spaces in default layout
set_space(object, spaces)
object |
a CrossLink object |
spaces |
A named list of numeric vectors or characters of "equal", "partition" and "flank" (see |
This function will only change default layout.
So, it is recommended to use this function after crosslink,
and before transformation.
an updated CrossLink object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.